import os
import sys
from datetime import datetime
from argparse import ArgumentParser, Namespace
from trainer.cogc_trainer_edit_v3 import EditProGaussianTrainer
from arguments.edit_pnp_transfer import ModelParams, PipelineParams, OptimizationParams



if __name__ == "__main__":
    parser = ArgumentParser(description="Training script parameters")
    lp = ModelParams(parser)
    op = OptimizationParams(parser)
    pp = PipelineParams(parser)
    args = parser.parse_args(sys.argv[1:])
    model_cfg = lp.extract(args)
    pipe_cfg = pp.extract(args)
    optim_cfg = op.extract(args)

    data_path = model_cfg.source_path
    model_cfg.guidance['prompt'] = model_cfg.guidance_prompt
    trainer = EditProGaussianTrainer(data_path, model_cfg, pipe_cfg, optim_cfg)
    
    start_time = datetime.now()
    if model_cfg.mode == "train":
        trainer.train_from_progressive()
    elif model_cfg.mode == "render":
        trainer.render_nvs(traj_opt=model_cfg.traj_opt)
    elif model_cfg.mode == "render_time":
        trainer.render_time()
    elif model_cfg.mode == "eval_nvs":
        trainer.eval_nvs()
    elif model_cfg.mode == "eval_pose":
        trainer.eval_pose()
    end_time = datetime.now()
    print('Duration: {}'.format(end_time - start_time))

